@@ -15,41 +15,20 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed.c,v 1.48 2004/11/16 14:21:23 chpe Exp $
+ *  $Id: ephy-embed.c,v 1.58 2005/01/30 15:20:35 chpe Exp $
  */
 
 #include "config.h"
 
 #include "ephy-embed.h"
 
+#include "ephy-embed-type-builtins.h"
 #include "ephy-marshal.h"
 #include "mozilla-embed-single.h"
 #include "mozilla-embed.h"
 
 static void ephy_embed_base_init (gpointer g_class);
 
-GType
-ephy_embed_chrome_get_type (void)
-{
-	static GType etype = 0;
-
-	if (etype == 0)
-	{
-		static const GFlagsValue values[] =
-		{
-		{ EPHY_EMBED_CHROME_MENUBAR, "EPHY_EMBED_CHROME_MENUBAR", "menubar" },
-		{ EPHY_EMBED_CHROME_TOOLBAR, "EPHY_EMBED_CHROME_TOOLBAR", "toolbar" },
-		{ EPHY_EMBED_CHROME_STATUSBAR, "EPHY_EMBED_CHROME_STATUSBAR", "statusbar" },
-		{ EPHY_EMBED_CHROME_BOOKMARKSBAR, "EPHY_EMBED_CHROME_BOOKMARKSBAR", "bookmarksbar" },
-		{ 0, NULL, NULL }
-		};
-
-		etype = g_flags_register_static ("EphyEmbedChrome", values);
-	}
-
-	return etype;
-}
-
 GType
 ephy_embed_get_type (void)
 {
@@ -82,22 +61,20 @@ ephy_embed_base_init (gpointer g_class)
 /**
  * EphyEmbed::ge-new-window:
  * @embed:
- * @new_embed: a newly-generated child #EphyEmbed
- * @mask: @new_embed's #EphyChromeMask
+ * @new_embed: the newly opened #EphyEmbed
  *
- * The ::ge_new_window signal is emitted when a new window has been opened by
+ * The ::ge_new_window signal is emitted after a new window has been opened by
  * the embed. For example, when a JavaScript popup window is opened.
  **/
 		g_signal_new ("ge_new_window",
 			      EPHY_TYPE_EMBED,
-			      G_SIGNAL_RUN_FIRST,
+			      G_SIGNAL_RUN_FIRST | G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (EphyEmbedIface, new_window),
 			      NULL, NULL,
-			      ephy_marshal_VOID__POINTER_INT,
+			      g_cclosure_marshal_VOID__OBJECT,
 			      G_TYPE_NONE,
-			      2,
-			      G_TYPE_POINTER,
-			      G_TYPE_INT);
+			      1,
+			      GTK_TYPE_WIDGET);
 /**
  * EphyEmbed::ge-popup-blocked:
  * @embed:
@@ -115,8 +92,8 @@ ephy_embed_base_init (gpointer g_class)
 			      ephy_marshal_VOID__STRING_STRING,
 			      G_TYPE_NONE,
 			      2,
-			      G_TYPE_POINTER,
-			      G_TYPE_POINTER);
+			      G_TYPE_STRING,
+			      G_TYPE_STRING);
 /**
  * EphyEmbed::ge-context-menu:
  * @embed:
@@ -188,11 +165,11 @@ ephy_embed_base_init (gpointer g_class)
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (EphyEmbedIface, net_state),
 			      NULL, NULL,
-			      ephy_marshal_VOID__STRING_INT,
+			      ephy_marshal_VOID__STRING_FLAGS,
 			      G_TYPE_NONE,
 			      2,
 			      G_TYPE_STRING,
-			      G_TYPE_INT);
+			      EPHY_TYPE_EMBED_NET_STATE);
 /**
  * EphyEmbed::ge-dom-mouse-click:
  * @embed:
@@ -229,7 +206,7 @@ ephy_embed_base_init (gpointer g_class)
 /**
  * EphyEmbed::ge-security-change:
  * @embed:
- * @level: @embed's new #EmbedSecurityLevel
+ * @level: @embed's new #EphyEmbedSecurityLevel
  *
  * The ::ge_security_change signal is emitted when the security level of @embed
  * changes. For example, this will happen when the user browses from an
@@ -240,10 +217,10 @@ ephy_embed_base_init (gpointer g_class)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (EphyEmbedIface, security_change),
 			      NULL, NULL,
-			      g_cclosure_marshal_VOID__INT,
+			      g_cclosure_marshal_VOID__ENUM,
 			      G_TYPE_NONE,
 			      1,
-			      G_TYPE_INT);
+			      EPHY_TYPE_EMBED_SECURITY_LEVEL);
 /**
  * EphyEmbed::ge-zoom-change:
  * @embed:
@@ -318,6 +295,23 @@ ephy_embed_base_init (gpointer g_class)
 			      G_TYPE_NONE,
 			      0);
 
+/**
+ * EphyEmbed::ge-document-type:
+ * @embed:
+ * @type: the new document type
+ *
+ * The ::ge-document-type signal is emitted when @embed determines the type of its document.
+ **/
+		g_signal_new ("ge_document_type",
+			      EPHY_TYPE_EMBED,
+			      G_SIGNAL_RUN_FIRST,
+			      G_STRUCT_OFFSET (EphyEmbedIface, document_type),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__ENUM,
+			      G_TYPE_NONE,
+			      1,
+			      EPHY_TYPE_EMBED_DOCUMENT_TYPE);
+
 		initialized = TRUE;
 	}
 }
@@ -656,12 +650,12 @@ ephy_embed_shistory_go_nth (EphyEmbed *embed,
  * @level: return value of security level
  * @description: return value of the description of the security level
  *
- * Fetches the #EmbedSecurityLevel and a newly-allocated string description
+ * Fetches the #EphyEmbedSecurityLevel and a newly-allocated string description
  * of the security state of @embed.
  **/
 void
 ephy_embed_get_security_level (EphyEmbed *embed,
-			       EmbedSecurityLevel *level,
+			       EphyEmbedSecurityLevel *level,
 			       char **description)
 {
 	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
@@ -825,13 +819,13 @@ ephy_embed_print_preview_n_pages (EphyEmbed *embed)
  * ephy_embed_print_preview_navigate:
  * @embed: an #EphyEmbed
  * @type: an #EphyPrintPreviewNavType which determines where to navigate
- * @page: if @type is %PRINTPREVIEW_GOTO_PAGENUM, the desired page number
+ * @page: if @type is %EPHY_EMBED_PRINTPREVIEW_GOTO_PAGENUM, the desired page number
  *
  * Navigates @embed's print preview.
  **/
 void
 ephy_embed_print_preview_navigate (EphyEmbed *embed,
-				   EmbedPrintPreviewNavType type,
+				   EphyEmbedPrintPreviewNavType type,
 				   int page)
 {
 	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
