@@ -15,12 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history.c,v 1.52 2004/11/11 14:19:17 chpe Exp $
+ *  $Id: ephy-history.c,v 1.56 2005/01/30 20:09:58 chpe Exp $
  */
 
 #include "config.h"
 
 #include "ephy-history.h"
+#include "ephy-marshal.h"
 #include "ephy-file-helpers.h"
 #include "ephy-debug.h"
 #include "ephy-node-db.h"
@@ -44,7 +45,7 @@
 
 #define EPHY_HISTORY_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_HISTORY, EphyHistoryPrivate))
 
-struct EphyHistoryPrivate
+struct _EphyHistoryPrivate
 {
 	char *xml_file;
 	EphyNodeDb *db;
@@ -70,6 +71,7 @@ enum
 {
 	VISITED,
 	CLEARED,
+	REDIRECT,
         LAST_SIGNAL
 };
 
@@ -113,7 +115,7 @@ static void
 ephy_history_set_enabled (EphyHistory *history,
 			  gboolean enabled)
 {
-	LOG ("ephy_history_set_enabled %d", enabled)
+	LOG ("ephy_history_set_enabled %d", enabled);
 
 	history->priv->enabled = enabled;
 
@@ -197,7 +199,19 @@ ephy_history_class_init (EphyHistoryClass *klass)
                               G_TYPE_NONE,
                               0);
 
-	g_type_class_add_private (object_class, sizeof(EphyHistoryPrivate));
+	signals[REDIRECT] =
+                g_signal_new ("redirect",
+                              G_OBJECT_CLASS_TYPE (object_class),
+                              G_SIGNAL_RUN_FIRST,
+                              G_STRUCT_OFFSET (EphyHistoryClass, redirect),
+                              NULL, NULL,
+                              ephy_marshal_VOID__STRING_STRING,
+                              G_TYPE_NONE,
+                              2,
+			      G_TYPE_STRING,
+			      G_TYPE_STRING);
+
+	g_type_class_add_private (object_class, sizeof (EphyHistoryPrivate));
 }
 
 static gboolean
@@ -253,7 +267,7 @@ ephy_history_save (EphyHistory *eb)
 		return;
 	}
 
-	LOG ("Saving history db")
+	LOG ("Saving history db");
 
 	ret = ephy_node_db_write_to_xml_safe
 		(eb->priv->db, eb->priv->xml_file,
@@ -602,7 +616,7 @@ ephy_history_finalize (GObject *object)
 }
 
 EphyHistory *
-ephy_history_new ()
+ephy_history_new (void)
 {
 	return EPHY_HISTORY (g_object_new (EPHY_TYPE_HISTORY, NULL));
 }
@@ -615,7 +629,7 @@ ephy_history_host_visited (EphyHistory *eh,
 	GValue value = { 0, };
 	int visits;
 
-	LOG ("Host visited")
+	LOG ("Host visited");
 
 	visits = ephy_node_get_property_int
 		(host, EPHY_NODE_PAGE_PROP_VISITS);
@@ -904,7 +918,7 @@ ephy_history_set_page_title (EphyHistory *gh,
 	EphyNode *node;
 	GValue value = { 0, };
 
-	LOG ("Set page title")
+	LOG ("Set page title");
 
 	if (title == NULL || title[0] == '\0') return;
 
@@ -945,7 +959,7 @@ ephy_history_set_icon (EphyHistory *gh,
 {
 	EphyNode *host;
 
-	LOG ("Set host icon")
+	LOG ("Set host icon");
 
 	host = g_hash_table_lookup (gh->priv->hosts_hash, url);
 	if (host)
@@ -965,7 +979,7 @@ ephy_history_clear (EphyHistory *gh)
 {
 	EphyNode *node;
 
-	LOG ("clearing history")
+	LOG ("clearing history");
 
 	ephy_node_db_set_immutable (gh->priv->db, FALSE);
 
