@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyHistoryListener.cpp,v 1.3 2004/12/02 16:14:15 chpe Exp $
+ *  $Id: EphyHistoryListener.cpp,v 1.4 2005/01/28 22:23:38 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -45,12 +45,12 @@
  
 EphyHistoryListener::EphyHistoryListener ()
 {
-	LOG ("EphyHistoryListener ctor")
+	LOG ("EphyHistoryListener ctor");
 }
 
 EphyHistoryListener::~EphyHistoryListener ()
 {
-	LOG ("EphyHistoryListener dtor")
+	LOG ("EphyHistoryListener dtor");
 }
 
 nsresult
