@@ -16,14 +16,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphySingle.cpp,v 1.17.4.1 2004/11/13 19:56:49 chpe Exp $
+ *  $Id: EphySingle.cpp,v 1.22 2005/01/28 22:23:38 chpe Exp $
  */
 
 #include "mozilla-config.h"
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "EphySingle.h"
 
@@ -48,7 +46,7 @@ NS_IMPL_ISUPPORTS1(EphySingle, nsIObserver)
 EphySingle::EphySingle()
 : mOwner(nsnull)
 {
-	LOG ("EphySingle ctor")
+	LOG ("EphySingle ctor");
 }
 
 nsresult
@@ -67,7 +65,7 @@ EphySingle::Init (EphyEmbedSingle *aOwner)
 
 	mOwner = aOwner;
 
-	LOG ("EphySingle::Init")
+	LOG ("EphySingle::Init");
 
 	return NS_OK;
 }
@@ -75,7 +73,7 @@ EphySingle::Init (EphyEmbedSingle *aOwner)
 nsresult
 EphySingle::Detach ()
 {
-	LOG ("EphySingle::Detach")
+	LOG ("EphySingle::Detach");
 
 	if (mObserverService)
 	{
@@ -91,7 +89,7 @@ EphySingle::Detach ()
 
 EphySingle::~EphySingle()
 {
-	LOG ("EphySingle dtor")
+	LOG ("EphySingle dtor");
 
 	mOwner = nsnull;
 }
@@ -100,7 +98,7 @@ nsresult
 EphySingle::EmitCookieNotification (const char *name,
 				    nsISupports *aSubject)
 {
-	LOG ("EmitCookieNotification %s", name)
+	LOG ("EmitCookieNotification %s", name);
 
 	nsCOMPtr<nsICookie> cookie = do_QueryInterface (aSubject);
 	NS_ENSURE_TRUE (cookie, NS_ERROR_FAILURE);
@@ -118,7 +116,7 @@ nsresult
 EphySingle::EmitPermissionNotification (const char *name,
 					nsISupports *aSubject)
 {
-	LOG ("EmitPermissionNotification %s", name)
+	LOG ("EmitPermissionNotification %s", name);
 
 	nsCOMPtr<nsIPermission> perm = do_QueryInterface (aSubject);
 	NS_ENSURE_TRUE (perm, NS_ERROR_FAILURE);
@@ -140,7 +138,7 @@ NS_IMETHODIMP EphySingle::Observe(nsISupports *aSubject,
 {
 	nsresult rv = NS_OK;
 
-	LOG ("EphySingle::Observe topic %s", aTopic)
+	LOG ("EphySingle::Observe topic %s", aTopic);
 
 	if (strcmp (aTopic, "cookie-changed") == 0)
 	{
@@ -162,7 +160,7 @@ NS_IMETHODIMP EphySingle::Observe(nsISupports *aSubject,
 		/* "cleared" */
 		else if (aData[0] == 'c' && aData[1] == 'l')
 		{
-			LOG ("EphySingle::cookie-changed::cleared")
+			LOG ("EphySingle::cookie-changed::cleared");
 
 			g_signal_emit_by_name (EPHY_COOKIE_MANAGER (mOwner), "cookies-cleared");
 		}
@@ -174,7 +172,7 @@ NS_IMETHODIMP EphySingle::Observe(nsISupports *aSubject,
 	}
 	else if (strcmp (aTopic, "cookie-rejected") == 0)
 	{
-		LOG ("EphySingle::cookie-rejected")
+		LOG ("EphySingle::cookie-rejected");
 
 		nsCOMPtr<nsIURI> uri = do_QueryInterface (aSubject);
 		if (uri)
@@ -209,7 +207,7 @@ NS_IMETHODIMP EphySingle::Observe(nsISupports *aSubject,
 		/* "cleared" */
 		else if (aData[0] == 'c' && aData[1] == 'l')
 		{
-			LOG ("EphySingle::perm-changed::cleared")
+			LOG ("EphySingle::perm-changed::cleared");
 
 			g_signal_emit_by_name (EPHY_PERMISSION_MANAGER (mOwner), "permissions-cleared");
 		}
@@ -242,7 +240,7 @@ NS_IMETHODIMP EphySingle::Observe(nsISupports *aSubject,
 		rv = NS_ERROR_FAILURE;
 	}
 
-	LOG ("EphySingle::Observe %s", NS_SUCCEEDED (rv) ? "success" : "FAILURE")
+	LOG ("EphySingle::Observe %s", NS_SUCCEEDED (rv) ? "success" : "FAILURE");
 
 	return rv;
 }
@@ -278,14 +276,6 @@ mozilla_cookie_to_ephy_cookie (nsICookie *cookie)
 	cookie->GetIsSecure (&isSecure);
 	info->is_secure = isSecure != PR_FALSE;
 
-	nsCookieStatus status;
-	cookie->GetStatus (&status);
-	info->p3p_state = status;
-
-	nsCookiePolicy policy;
-	cookie->GetPolicy (&policy);
-	info->p3p_policy = policy;
-
 	PRUint64 dateTime;
 	cookie->GetExpires (&dateTime);
 	info->expires = dateTime;
