@@ -15,14 +15,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-persist.cpp,v 1.43 2004/10/27 19:54:56 chpe Exp $
+ *  $Id: mozilla-embed-persist.cpp,v 1.46 2005/01/05 20:09:09 chpe Exp $
  */
 
 #include "mozilla-config.h"
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "mozilla-embed-persist.h"
 #include "mozilla-embed.h"
@@ -140,7 +138,7 @@ impl_save (EphyEmbedPersist *persist)
 	char *uri;
 	long max_size;
 	EphyEmbed *embed;
-	EmbedPersistFlags flags;
+	EphyEmbedPersistFlags flags;
 	EphyEmbedSingle *single;
 
 	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (embed_shell));
@@ -155,7 +153,7 @@ impl_save (EphyEmbedPersist *persist)
 		      "max_size", &max_size,
 		      NULL);
 
-	g_return_val_if_fail (!(flags & EMBED_PERSIST_COPY_PAGE)
+	g_return_val_if_fail (!(flags & EPHY_EMBED_PERSIST_COPY_PAGE)
 			      || embed != NULL, FALSE);	
 
 	EphyBrowser *browser = NULL;
@@ -220,7 +218,7 @@ impl_save (EphyEmbedPersist *persist)
 	nsCOMPtr<nsIDOMDocument> DOMDocument;
 	if (!uri)
 	{		
-		if (flags & EMBED_PERSIST_MAINDOC)
+		if (flags & EPHY_EMBED_PERSIST_MAINDOC)
 		{
                 	browser->GetDocument (getter_AddRefs(DOMDocument));
 		}
@@ -243,7 +241,7 @@ impl_save (EphyEmbedPersist *persist)
 	 * the page, which will possibly give a different page than the original which we
 	 * need for view source
 	 */
-	NS_ENSURE_TRUE (!(flags & EMBED_PERSIST_COPY_PAGE) || pageDescriptor, FALSE);
+	NS_ENSURE_TRUE (!(flags & EPHY_EMBED_PERSIST_COPY_PAGE) || pageDescriptor, FALSE);
 
 	if (filename == NULL)
 	{
@@ -286,7 +284,7 @@ impl_to_string (EphyEmbedPersist *persist)
 {
 	EphyEmbed *embed;
 	nsCOMPtr<nsIDOMDocument> DOMDocument;
-	EmbedPersistFlags flags;
+	EphyEmbedPersistFlags flags;
 	EphyBrowser *browser;
 	nsresult rv = NS_OK;
 
@@ -302,7 +300,7 @@ impl_to_string (EphyEmbedPersist *persist)
 	browser = (EphyBrowser *) _mozilla_embed_get_ephy_browser (MOZILLA_EMBED(embed));
 	g_assert (browser != NULL);
 
-	if (flags & EMBED_PERSIST_MAINDOC)
+	if (flags & EPHY_EMBED_PERSIST_MAINDOC)
 	{
 		rv = browser->GetDocument (getter_AddRefs(DOMDocument));
 	}
