@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node-filter.h,v 1.2 2003/11/19 19:19:52 chpe Exp $
+ *  $Id: ephy-node-filter.h,v 1.3 2005/01/08 19:41:46 chpe Exp $
  */
 
 #ifndef EPHY_NODE_FILTER_H
@@ -35,7 +35,7 @@ G_BEGIN_DECLS
 #define EPHY_IS_NODE_FILTER_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_NODE_FILTER))
 #define EPHY_NODE_FILTER_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_NODE_FILTER, EphyNodeFilterClass))
 
-typedef struct EphyNodeFilterPrivate EphyNodeFilterPrivate;
+typedef struct _EphyNodeFilterPrivate EphyNodeFilterPrivate;
 
 typedef struct
 {
@@ -70,7 +70,7 @@ typedef enum
 	EPHY_NODE_FILTER_EXPRESSION_INT_PROP_LESS_THAN     /* args: int prop_id, int int */
 } EphyNodeFilterExpressionType;
 
-typedef struct EphyNodeFilterExpression EphyNodeFilterExpression;
+typedef struct _EphyNodeFilterExpression EphyNodeFilterExpression;
 
 /* The filter starts iterating over all expressions at level 0,
  * if one of them is TRUE it continues to level 1, etc.
