@@ -16,12 +16,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarks.c,v 1.98 2005/01/08 19:41:47 chpe Exp $
+ *  $Id: ephy-bookmarks.c,v 1.103 2005/02/01 23:42:48 chpe Exp $
  */
 
 #include "config.h"
 
 #include "ephy-bookmarks.h"
+#include "ephy-bookmarks-type-builtins.h"
 #include "ephy-file-helpers.h"
 #include "ephy-embed-shell.h"
 #include "ephy-shell.h"
@@ -138,6 +139,10 @@ ephy_bookmarks_get_type (void)
                         0, /* n_preallocs */
                         (GInstanceInitFunc) ephy_bookmarks_init
                 };
+		volatile GType flags_type; /* work around gcc's optimiser */
+      
+		/* make sure the flags type is known */
+	      	flags_type = EPHY_TYPE_BOOKMARK_PROPERTY;
 
                 type = g_type_register_static (G_TYPE_OBJECT,
 					       "EphyBookmarks",
@@ -214,7 +219,7 @@ ephy_bookmarks_get_toolbars_model (EphyBookmarks *eb)
 {
 	g_return_val_if_fail (EPHY_IS_BOOKMARKS (eb), NULL);
 
-	LOG ("ephy_bookmarks_get_toolbars_model")
+	LOG ("ephy_bookmarks_get_toolbars_model");
 
 	if (eb->priv->toolbars_model == NULL)
 	{
@@ -308,7 +313,7 @@ static void
 ephy_bookmarks_save (EphyBookmarks *eb)
 {
 
-	LOG ("Saving bookmarks")
+	LOG ("Saving bookmarks");
 
 	ephy_node_db_write_to_xml_safe
 		(eb->priv->db,
@@ -538,16 +543,16 @@ redirect_cb (EphyHistory *history,
 	gtk_message_dialog_format_secondary_markup
 		(GTK_MESSAGE_DIALOG (dialog),
 		/* translators: the %s is a URL */
-		_("The bookmarked page has moved to <tt>%s</tt>."),
+		_("The bookmarked page has moved to \"%s\"."),
 		to_uri);
 
 	gtk_dialog_add_button (GTK_DIALOG (dialog),
-				_("_Don't update bookmark"), GTK_RESPONSE_REJECT);
+				_("_Don't Update"), GTK_RESPONSE_REJECT);
 	gtk_dialog_add_button (GTK_DIALOG (dialog),
-				_("_Update bookmark"), GTK_RESPONSE_ACCEPT);
+				_("_Update"), GTK_RESPONSE_ACCEPT);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_REJECT);
 
-	gtk_window_set_title (GTK_WINDOW (dialog), _("Update bookmark?"));
+	gtk_window_set_title (GTK_WINDOW (dialog), _("Update Bookmark?"));
 	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
 
 	g_object_set_data_full (G_OBJECT (dialog), UPDATE_URI_DATA_KEY,
@@ -559,6 +564,9 @@ redirect_cb (EphyHistory *history,
 					 (EphyNodeCallback) update_bookmark_destroy_cb,
 					 G_OBJECT (dialog));
 
+	/* this dialogue is unexpected */
+	gtk_window_set_focus_on_map (GTK_WINDOW (dialog), FALSE);
+
 	gtk_window_present (GTK_WINDOW (dialog));
 }
 
@@ -909,7 +917,7 @@ ephy_bookmarks_finalize (GObject *object)
 	ephy_bookmarks_save (eb);
 
 	/* have to do this before unreffing the nodes */
-        LOG ("Unref bookmarks toolbars model")
+        LOG ("Unref bookmarks toolbars model");
         if (eb->priv->toolbars_model != NULL)
         {
                 g_object_unref (eb->priv->toolbars_model);
@@ -925,13 +933,13 @@ ephy_bookmarks_finalize (GObject *object)
 	g_free (eb->priv->xml_file);
 	g_free (eb->priv->rdf_file);
 
-	LOG ("Bookmarks finalized")
+	LOG ("Bookmarks finalized");
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 EphyBookmarks *
-ephy_bookmarks_new ()
+ephy_bookmarks_new (void)
 {
 	EphyBookmarks *eb;
 
@@ -1370,7 +1378,7 @@ ephy_bookmarks_find_keyword (EphyBookmarks *eb,
 
 	if (g_utf8_strlen (name, -1) == 0)
 	{
-		LOG ("Empty name, no keyword matches.")
+		LOG ("Empty name, no keyword matches.");
 		return NULL;
 	}
 
@@ -1430,7 +1438,7 @@ ephy_bookmarks_set_keyword (EphyBookmarks *eb,
 
 	if (ephy_node_has_child (eb->priv->notcategorized, bookmark))
 	{
-		LOG ("Remove from categorized bookmarks")
+		LOG ("Remove from categorized bookmarks");
 		ephy_node_remove_child
 			(eb->priv->notcategorized, bookmark);
 	}
@@ -1452,7 +1460,7 @@ ephy_bookmarks_unset_keyword (EphyBookmarks *eb,
 	if (!bookmark_is_categorized (eb, bookmark) &&
 	    !ephy_node_has_child (eb->priv->notcategorized, bookmark))
 	{
-		LOG ("Add to not categorized bookmarks")
+		LOG ("Add to not categorized bookmarks");
 		ephy_node_add_child
 			(eb->priv->notcategorized, bookmark);
 	}
