@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-navigation-action.c,v 1.23 2005/01/06 18:14:42 chpe Exp $
+ *  $Id: ephy-navigation-action.c,v 1.24 2005/01/28 22:24:46 chpe Exp $
  */
 
 #include "config.h"
@@ -279,7 +279,7 @@ menu_activated_cb (GtkMenuToolButton *button,
 {
 	GtkWidget *menu = NULL;
 
-	LOG ("menu_activated_cb dir %d", action->priv->direction)
+	LOG ("menu_activated_cb dir %d", action->priv->direction);
 
 	switch (action->priv->direction)
 	{
@@ -316,7 +316,7 @@ set_tooltip_cb (GtkMenuToolButton *proxy,
 static void
 connect_proxy (GtkAction *action, GtkWidget *proxy)
 {
-	LOG ("Connect navigation action proxy")
+	LOG ("Connect navigation action proxy");
 
 	if (GTK_IS_MENU_TOOL_BUTTON (proxy))
 	{
